Environment

Trait Environment 

pub trait Environment: AutoTraits {
    type Storage: Storage<Context = Self::StorageContext>;
    type Network: Network<Node = Self::ValidatorNode>;
    type Signer: Signer;
    type Wallet: Wallet;
    type ValidatorNode: ValidatorNode + AutoTraits + Clone;
    type StorageContext: Context<Extra: ExecutionRuntimeContext> + AutoTraits;

    // Required methods
    fn storage(&self) -> &Self::Storage;
    fn network(&self) -> &Self::Network;
    fn signer(&self) -> &Self::Signer;
    fn wallet(&self) -> &Self::Wallet;
}
The collection of services (storage, network, signer and wallet) available to the client.

Required Associated Types

type Storage: Storage<Context = Self::StorageContext>

The persistent storage backend.

type Network: Network<Node = Self::ValidatorNode>

The provider of validator nodes.

type Signer: Signer

The signer used to sign on behalf of chain owners.

type Wallet: Wallet

The wallet tracking the chains followed by the client.

type ValidatorNode: ValidatorNode + AutoTraits + Clone

The validator node type produced by the network provider.

type StorageContext: Context<Extra: ExecutionRuntimeContext> + AutoTraits

The storage context used by the storage backend.

Required Methods

fn storage(&self) -> &Self::Storage

Returns a reference to the storage backend.

fn network(&self) -> &Self::Network

Returns a reference to the network provider.

fn signer(&self) -> &Self::Signer

Returns a reference to the signer.

fn wallet(&self) -> &Self::Wallet

Returns a reference to the wallet.

Implementors