pub type Test = Impl<TestStorage, TestNetwork, TestSigner, TestWallet>;Expand description
A fully in-memory Environment used in tests.
Aliased Type
pub struct Test {
pub storage: DbStorage<MemoryDatabase, TestClock>,
pub network: NodeProvider<DbStorage<MemoryDatabase, TestClock>>,
pub signer: InMemorySigner,
pub wallet: Memory,
}Fields
storage: DbStorage<MemoryDatabase, TestClock>The persistent storage backend.
network: NodeProvider<DbStorage<MemoryDatabase, TestClock>>The provider of validator nodes.
signer: InMemorySignerThe signer used to sign on behalf of chain owners.
wallet: MemoryThe wallet tracking the chains followed by the client.